# Helpers

Repository for various helper functions that I regularly use. 

**SGA:** Genetic algorithm functions

**arbitraryNN**: Pytorch based Neural Network which can accept an arbitrary number of layers as a parameter

**cross_validation**: Function that outputs the cross validated score for a model